==> vradi-swing-0.0.3-sources.jar: com/jurismarches/vradi/ui/search/CriteriaField.java <==
package com.jurismarches.vradi.ui.search;

import com.jurismarches.vradi.VradiContext;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.ui.UIHelper;
import com.jurismarches.vradi.ui.search.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.JAXXBinding;
import jaxx.runtime.JAXXContext;
import jaxx.runtime.JAXXObject;
import jaxx.runtime.JAXXObjectDescriptor;
import jaxx.runtime.SwingUtil;
import jaxx.runtime.Util;
import jaxx.runtime.binding.DefaultJAXXBinding;
import jaxx.runtime.binding.SimpleJAXXObjectBinding;
import jaxx.runtime.swing.EntityComboBox;
import jaxx.runtime.swing.HBox;
import jaxx.runtime.swing.Item;
import jaxx.runtime.swing.JAXXButtonGroup;
import jaxx.runtime.swing.Table;
import jaxx.runtime.swing.VBox;
import jaxx.runtime.swing.editor.*;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import static jaxx.runtime.SwingUtil.createImageIcon;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static org.nuiton.i18n.I18n._;
import static org.nuiton.i18n.I18n.n_;

public class CriteriaField extends jaxx.runtime.swing.Table implements JAXXObject {

    /*-----------------------------------------------------------------------*/
    /*---------------- Constants for all javaBean properties ----------------*/
    /*-----------------------------------------------------------------------*/

    public static final String PROPERTY_BEAN = "bean";
    public static final String PROPERTY_DELETABLE = "deletable";
    public static final String PROPERTY_LABEL_NAME = "labelName";

    /*-----------------------------------------------------------------------*/
    /*------------------ Constants for all public bindings ------------------*/
    /*-----------------------------------------------------------------------*/

    public static final String BINDING_LABEL_TEXT = "label.text";

    /*-----------------------------------------------------------------------*/
    /*------------------------- Other static fields -------------------------*/
    /*-----------------------------------------------------------------------*/

    private static final String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1TPW8TQRAdmzjBCR8BK1EighQgolzTB0GIkUUiEyRMEeGGPd/IXrO+XXb34gsF4ifwE6CnQaKjQhTUFDSIv4AQBS1i9s7x2cQIrtiTZt+8eTP75vU3KFkDl3o8SZiJIyf6yHZv7e/fC3rYdrfRto3QThnIvkIRii1YCEdx6+BKq+HTq8P0ak31tYowGsvebMC8dYcSbRfRObg4mdG2ttocXW8mOjZHrCNR01hf/vhefBE+f1UESDSpm6NW1v+VlXcy04CiCB2cp0oHvCp51CEZRkQd0nvax2qSW7vH+/gEnsFcA2Y1N0Tm4PL/t5xypPmJploHhoeiZoRDI3hdoCQBrK36rBcbYfvctLtoWYpisWAWfYRNJGid8s06KEseoPQCHSx6wcw3wbImcthMgDyiqSvTYbbrW+goNhCPhXOH7IFB3FMhjrGGKNHxgA44l7NuKyWJJ8dVNpppszuRcIJL8RTNNQdX0wegjrSQaFg2D3YMmdOU0iZoNL5UwuyAtLPdhg96RDkHEmmgHCxNAGs+uK2SIdbAhQkHkLdY7q388QstKJmYwg5WWsfteJ+uMiOu/GFET5je/lqufH739W39yH0Fqr00FTq2POQKbZRG44QvfTazXuyErN7lerMFZUvDb2ebtTZFWHN4TeKoXvY8Pp3d4bZLFKW5L+8/LD/6dAKKdZiXiod17vE7UHZdQ1NQMkz0za1U0anBSToXvTZyicOErH3mesgdXw9EFNJ8byQ0grUpIxjpCMoff1aab7bGx7D6V3g+itJDmBWRFBGmazjcsKlrt6AtxqHKN2nabhX8f1Vr/RsZhrrr1AQAAA==";
    protected static final Log log = LogFactory.getLog(com.jurismarches.vradi.ui.search.CriteriaField.class);
    private static final long serialVersionUID = 1L;

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Internal states ---------------------------*/
    /*-----------------------------------------------------------------------*/

    protected java.util.List<Object> $activeBindings = new ArrayList<Object>();
    protected Map<String, Object> $bindingSources = new HashMap<String, Object>();
    protected final Map<String, JAXXBinding> $bindings = new java.util.TreeMap<String, JAXXBinding>();
    protected Map<String, Object> $objectMap = new HashMap<String, Object>();
    protected Map<?,?> $previousValues = new java.util.HashMap<Object, Object>();
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    protected final JAXXContext delegateContext = new jaxx.runtime.context.DefaultJAXXContext();

    /*-----------------------------------------------------------------------*/
    /*------------------------ Protected components  ------------------------*/
    /*-----------------------------------------------------------------------*/

    protected org.sharengo.wikitty.TreeNode bean;
    protected javax.swing.JComboBox combo;
    protected java.lang.Boolean deletable;
    protected javax.swing.JLabel label;
    protected java.lang.String labelName;
    protected CriteriaField vradiCriteriaField = this;

    /*-----------------------------------------------------------------------*/
    /*---------------------- Raw body code from script ----------------------*/
    /*-----------------------------------------------------------------------*/

    protected Item rootItem;
    
    
    protected SearchHandler getHandler() {
        return UIHelper.getHandler(this, SearchHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    void $afterCompleteSetup() {
    }
    
    public void init(){
        if (isDeletable()){
            addMouseListener(new MouseAdapter() {
    
                @Override
                public void mouseClicked(final MouseEvent mouseEvent) {
                    if (mouseEvent.getButton() == MouseEvent.BUTTON3){
    
                        JPopupMenu popup = new JPopupMenu();
                        JMenuItem menuRemoveCriteria = new JMenuItem();
                        menuRemoveCriteria.setText(_("vradi.menu.removeCriteria"));
                        menuRemoveCriteria.addActionListener(new ActionListener() {
    
                            @Override
                            public void actionPerformed(ActionEvent actionEvent) {
                                removeCriteriaSelected();
                            }
                        });
                        popup.add(menuRemoveCriteria);
                        popup.show(vradiCriteriaField, mouseEvent.getX(), mouseEvent.getY());
                    }
                }
            });
        }
    }
    
    protected void removeCriteriaSelected(){
        getHandler().removeCriteriaAndPersist(this, getBean());
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Statics methods ---------------------------*/
    /*-----------------------------------------------------------------------*/

    public static JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return Util.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*-----------------------------------------------------------------------*/
    /*---------------------------- Constructors  ----------------------------*/
    /*-----------------------------------------------------------------------*/

    public CriteriaField() {
        $initialize();
    }

    public CriteriaField(JAXXContext parentContext) {
        Util.initContext(this, parentContext);
        $initialize();
    }

    /*-----------------------------------------------------------------------*/
    /*---------------------- JAXXObject implementation ----------------------*/
    /*-----------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if (allComponentsCreated && $bindings.containsKey($binding)) {
            $bindings.get($binding).applyDataBinding();
        }
        processDataBinding($binding);
    }

    @Override
    public void firePropertyChange(String propertyName, Object oldValue, Object newValue) {
        super.firePropertyChange(propertyName, oldValue, newValue);
    }

    @Override
    public Map<String, Object> get$objectMap() {
        return $objectMap;
    }

    @Override
    public JAXXBinding[] getDataBindings() {
        return $bindings.values().toArray(new JAXXBinding[$bindings.size()]);
    }

    @Override
    public Object getObjectById(String id) {
        return $objectMap.get(id);
    }

    @Override
    public void processDataBinding(String $binding, boolean $force) {
        if (!$force && $activeBindings.contains($binding)) { 
            return;
        }
        $activeBindings.add($binding);
        try {
            if (allComponentsCreated && $bindings.containsKey($binding)) {
                $bindings.get($binding).processDataBinding();
            }
        } finally {
            $activeBindings.remove($binding);
        }
    }

    @Override
    public void processDataBinding(String $binding) {
        processDataBinding($binding, false);
    }

    @Override
    public void registerDataBinding(JAXXBinding binding) {
        $bindings.put(binding.getId(), binding);
    }

    @Override
    public void removeDataBinding(String $binding) {
        if (allComponentsCreated && $bindings.containsKey($binding)) {
            $bindings.get($binding).removeDataBinding();
        }
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- JAXXContext implementation  ---------------------*/
    /*-----------------------------------------------------------------------*/

    @Override
    public <T> T getContextValue(Class<T> clazz) {
        return delegateContext.getContextValue(clazz, null);
    }

    @Override
    public <T> T getContextValue(Class<T> clazz, String name) {
        return delegateContext.getContextValue(clazz, name);
    }

    @Override
    public JAXXContext getDelegateContext() {
        return delegateContext;
    }

    @Override
    public <O extends Container> O getParentContainer(Class<O> clazz) {
        return SwingUtil.getParentContainer(this, clazz);
    }

    @Override
    public <O extends Container> O getParentContainer(Object source, Class<O> clazz) {
        return SwingUtil.getParentContainer(source, clazz);
    }

    @Override
    public <T> void removeContextValue(Class<T> clazz) {
        delegateContext.removeContextValue(clazz, null);
    }

    @Override
    public <T> void removeContextValue(Class<T> clazz, String name) {
        delegateContext.removeContextValue(clazz, name);
    }

    @Override
    public <T> void setContextValue(T o) {
        delegateContext.setContextValue(o, null);
    }

    @Override
    public <T> void setContextValue(T o, String name) {
        delegateContext.setContextValue(o, name);
    }

    /*-----------------------------------------------------------------------*/
    /*----------------------- Public acessor methods  -----------------------*/
    /*-----------------------------------------------------------------------*/

    public org.sharengo.wikitty.TreeNode getBean() {
        return bean;
    }

    public javax.swing.JComboBox getCombo() {
        return combo;
    }

    public java.lang.Boolean getDeletable() {
        return deletable;
    }

    public javax.swing.JLabel getLabel() {
        return label;
    }

    public java.lang.String getLabelName() {
        return labelName;
    }

    public java.lang.Boolean isDeletable() {
        return deletable !=null && deletable;
    }

    /*-----------------------------------------------------------------------*/
    /*----------------------- Public mutator methods  -----------------------*/
    /*-----------------------------------------------------------------------*/

    public void setBean(org.sharengo.wikitty.TreeNode newValue) {
        org.sharengo.wikitty.TreeNode oldValue = this.bean;
        this.bean = newValue;
        firePropertyChange(PROPERTY_BEAN, oldValue, newValue);
    }

    public void setDeletable(java.lang.Boolean newValue) {
        java.lang.Boolean oldValue = this.deletable;
        this.deletable = newValue;
        firePropertyChange(PROPERTY_DELETABLE, oldValue, newValue);
    }

    public void setLabelName(java.lang.String newValue) {
        java.lang.String oldValue = this.labelName;
        this.labelName = newValue;
        firePropertyChange(PROPERTY_LABEL_NAME, oldValue, newValue);
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- Components creation methods ---------------------*/
    /*-----------------------------------------------------------------------*/

    protected void addChildrenToVradiCriteriaField() {
        if (!allComponentsCreated) {
            return;
        }
        add(label, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, 10, 2, new Insets(0, 0, 0, 0), 0, 0));
        add(combo, new GridBagConstraints(0, 1, 1, 1, 1.0, 0.0, 10, 2, new Insets(0, 0, 0, 0), 0, 0));
    }

    protected void createBean() {
        $objectMap.put("bean", bean = null);
    }

    protected void createCombo() {
        $objectMap.put("combo", combo = new javax.swing.JComboBox());
        combo.setName("combo");
    }

    protected void createDeletable() {
        $objectMap.put("deletable", deletable = false);
    }

    protected void createLabel() {
        $objectMap.put("label", label = new javax.swing.JLabel());
        label.setName("label");
    }

    protected void createLabelName() {
        $objectMap.put("labelName", labelName = "");
    }

    /*-----------------------------------------------------------------------*/
    /*------------------------ Internal jaxx methods ------------------------*/
    /*-----------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToVradiCriteriaField();
        
        // apply 1 data bindings
        Util.applyDataBinding(this, $bindings.keySet());
        
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        // registers 1 data bindings
        $registerDefaultBindings();
        $objectMap.put("vradiCriteriaField", this);
        createLabelName();
        createBean();
        createDeletable();
        rootItem = null;
        createLabel();
        createCombo();
        // inline creation of vradiCriteriaField
        setName("vradiCriteriaField");
        
        $completeSetup();
    }

    private void $registerDefaultBindings() {
        // register 1 data bindings
        registerDataBinding(new SimpleJAXXObjectBinding(this, BINDING_LABEL_TEXT, true ,"labelName") {
        
            @Override
            public void processDataBinding() {
                label.setText(_(getLabelName()));
            }
        });
    }

}

==> vradi-swing-0.0.4-sources.jar: com/jurismarches/vradi/ui/search/CriteriaField.java <==
package com.jurismarches.vradi.ui.search;

import com.jurismarches.vradi.VradiContext;
import com.jurismarches.vradi.entities.*;
import com.jurismarches.vradi.services.dto.*;
import com.jurismarches.vradi.ui.UIHelper;
import com.jurismarches.vradi.ui.search.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import jaxx.runtime.*;
import jaxx.runtime.JAXXBinding;
import jaxx.runtime.JAXXContext;
import jaxx.runtime.JAXXObject;
import jaxx.runtime.JAXXObjectDescriptor;
import jaxx.runtime.binding.DefaultJAXXBinding;
import jaxx.runtime.binding.SimpleJAXXObjectBinding;
import jaxx.runtime.swing.*;
import jaxx.runtime.swing.EntityComboBox;
import jaxx.runtime.swing.Item;
import jaxx.runtime.swing.editor.*;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import static jaxx.runtime.SwingUtil.createImageIcon;
import static jaxx.runtime.validator.BeanValidatorUtil.convert;
import static org.nuiton.i18n.I18n._;
import static org.nuiton.i18n.I18n.n_;

public class CriteriaField extends jaxx.runtime.swing.Table implements JAXXObject {

    /*-----------------------------------------------------------------------*/
    /*---------------- Constants for all javaBean properties ----------------*/
    /*-----------------------------------------------------------------------*/

    public static final String PROPERTY_ACTIF = "actif";
    public static final String PROPERTY_BEAN = "bean";
    public static final String PROPERTY_DELETABLE = "deletable";
    public static final String PROPERTY_LABEL_NAME = "labelName";

    /*-----------------------------------------------------------------------*/
    /*------------------ Constants for all public bindings ------------------*/
    /*-----------------------------------------------------------------------*/

    public static final String BINDING_COMBO_ENABLED = "combo.enabled";
    public static final String BINDING_LABEL_ENABLED = "label.enabled";
    public static final String BINDING_LABEL_TEXT = "label.text";

    /*-----------------------------------------------------------------------*/
    /*------------------------- Other static fields -------------------------*/
    /*-----------------------------------------------------------------------*/

    private static final String $jaxxObjectDescriptor = "H4sIAAAAAAAAAI1TPW8TQRAdO3EcJ3wEQqKgBBQ+JQSs6YMgxMgikQkSpohww97dYm9Y3y67e8mFAvET+AnQ0yDRUSEKagoaxF9AiIIWMXvn+GxygbjYO8++efNm7s2b71AyGs5s0jgmOgot7zKydmtj4563yXx7mxlfc2WlhvRXKEKxBZNBP24snGs1XHq1l16tya6SIQsHspcaMGHsjmCmw5i1cGo4wzem2uxfL8Uq0rusfVF5rK9+/ii+DF68LgLECtWNYyuL/8vKOhltQJEHFo5jpS1aFTRsowzNwzbqPexiNUGNWadd9hSeQ7kBY4pqJLNw9uAtJxxJfqyw1pamAa9pbpnmtM6ZQAHEl12yGWluulT7HWZIgiIRJ4a5CBlKUCrhG7NQEdRjwgm0MOUEE9cESZvIYKMeoyFOXeo2MR3XQluSbf6EW7tDHmjG1mXABlgDJpilHh5wLGNdkVIgT4YrUd/yx+7PiSw4fb6ZTGA15JZTwZ8xfc3CxeSrYJuKC6ZJOiSyBznAnXSG83L1Y2K2sSGy1nBBh6hkQCT1pIWZIWDNBVdk3MNqmB+yBRqOZIbLHFFoQUlHGLYw19rr0ft4lbpz7i93OsLk9vfs9Jf3397Vdy05grVncqEDG4VWUVoqpi13pY+mfowsF9W7VC21oGLwi/jpui3kCGv2rlEc1ku/mUsnd6jpIEWp/PXDx9lHn0egWIcJIWlQpw6/ChXb0TgFKYJY3VxOFB3aHsdzymmzUGahMwKa9Mj1gFq66PEwwBHfiHEKCzlT6EvxKp9+TTffLu9OooDKTu4Lz6ZReghjPBQ8ZMl69jYvdx0nlWFRILMNy9u5gnvOq561LiTnpbxWRy2Lrbu9EkfucTUR7d6qB+Rw4cv/YDiNDH8AigJ7EHIFAAA=";
    protected static final Log log = LogFactory.getLog(com.jurismarches.vradi.ui.search.CriteriaField.class);
    private static final long serialVersionUID = 1L;

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Internal states ---------------------------*/
    /*-----------------------------------------------------------------------*/

    protected java.util.List<Object> $activeBindings = new ArrayList<Object>();
    protected Map<String, Object> $bindingSources = new HashMap<String, Object>();
    protected final Map<String, JAXXBinding> $bindings = new java.util.TreeMap<String, JAXXBinding>();
    protected Map<String, Object> $objectMap = new HashMap<String, Object>();
    protected Map<?,?> $previousValues = new java.util.HashMap<Object, Object>();
    private boolean allComponentsCreated;
    private boolean contextInitialized = true;
    protected final JAXXContext delegateContext = new jaxx.runtime.context.DefaultJAXXContext();

    /*-----------------------------------------------------------------------*/
    /*------------------------ Protected components  ------------------------*/
    /*-----------------------------------------------------------------------*/

    protected java.lang.Boolean actif;
    protected org.sharengo.wikitty.TreeNode bean;
    protected javax.swing.JComboBox combo;
    protected java.lang.Boolean deletable;
    protected javax.swing.JLabel label;
    protected java.lang.String labelName;
    protected CriteriaField vradiCriteriaField = this;

    /*-----------------------------------------------------------------------*/
    /*---------------------- Raw body code from script ----------------------*/
    /*-----------------------------------------------------------------------*/

    protected Item rootItem;
    
    
    protected SearchHandler getHandler() {
        return UIHelper.getHandler(this, SearchHandler.class);
    }
    
    protected VradiContext getVradiContext() {
        return VradiContext.get();
    }
    
    void $afterCompleteSetup() {
    }
    
    public void init(){
        if (isDeletable()){
            addMouseListener(new MouseAdapter() {
    
                @Override
                public void mouseClicked(final MouseEvent mouseEvent) {
                    if (mouseEvent.getButton() == MouseEvent.BUTTON3){
    
                        JPopupMenu popup = new JPopupMenu();
                        JMenuItem menuRemoveCriteria = new JMenuItem();
                        menuRemoveCriteria.setText(_("vradi.menu.removeCriteria"));
                        menuRemoveCriteria.addActionListener(new ActionListener() {
    
                            @Override
                            public void actionPerformed(ActionEvent actionEvent) {
                                removeCriteriaSelected();
                            }
                        });
                        popup.add(menuRemoveCriteria);
                        popup.show(vradiCriteriaField, mouseEvent.getX(), mouseEvent.getY());
                    }
                }
            });
        }
    }
    
    protected void removeCriteriaSelected(){
        getHandler().removeCriteriaAndPersist(this, getBean());
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------------- Statics methods ---------------------------*/
    /*-----------------------------------------------------------------------*/

    public static JAXXObjectDescriptor $getJAXXObjectDescriptor() {
        return JAXXUtil.decodeCompressedJAXXObjectDescriptor($jaxxObjectDescriptor);
    }

    /*-----------------------------------------------------------------------*/
    /*---------------------------- Constructors  ----------------------------*/
    /*-----------------------------------------------------------------------*/

    public CriteriaField() {
        $initialize();
    }

    public CriteriaField(JAXXContext parentContext) {
        JAXXUtil.initContext(this, parentContext);
        $initialize();
    }

    /*-----------------------------------------------------------------------*/
    /*---------------------- JAXXObject implementation ----------------------*/
    /*-----------------------------------------------------------------------*/

    @Override
    public void applyDataBinding(String $binding) {
        if (allComponentsCreated && $bindings.containsKey($binding)) {
            $bindings.get($binding).applyDataBinding();
        }
        processDataBinding($binding);
    }

    @Override
    public void firePropertyChange(String propertyName, Object oldValue, Object newValue) {
        super.firePropertyChange(propertyName, oldValue, newValue);
    }

    @Override
    public Map<String, Object> get$objectMap() {
        return $objectMap;
    }

    @Override
    public JAXXBinding[] getDataBindings() {
        return $bindings.values().toArray(new JAXXBinding[$bindings.size()]);
    }

    @Override
    public Object getObjectById(String id) {
        return $objectMap.get(id);
    }

    @Override
    public void processDataBinding(String $binding, boolean $force) {
        if (!$force && $activeBindings.contains($binding)) { 
            return;
        }
        $activeBindings.add($binding);
        try {
            if (allComponentsCreated && $bindings.containsKey($binding)) {
                $bindings.get($binding).processDataBinding();
            }
        } finally {
            $activeBindings.remove($binding);
        }
    }

    @Override
    public void processDataBinding(String $binding) {
        processDataBinding($binding, false);
    }

    @Override
    public void registerDataBinding(JAXXBinding binding) {
        $bindings.put(binding.getId(), binding);
    }

    @Override
    public void removeDataBinding(String $binding) {
        if (allComponentsCreated && $bindings.containsKey($binding)) {
            $bindings.get($binding).removeDataBinding();
        }
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- JAXXContext implementation  ---------------------*/
    /*-----------------------------------------------------------------------*/

    @Override
    public <T> T getContextValue(Class<T> clazz) {
        return delegateContext.getContextValue(clazz, null);
    }

    @Override
    public <T> T getContextValue(Class<T> clazz, String name) {
        return delegateContext.getContextValue(clazz, name);
    }

    @Override
    public JAXXContext getDelegateContext() {
        return delegateContext;
    }

    @Override
    public <O extends Container> O getParentContainer(Class<O> clazz) {
        return SwingUtil.getParentContainer(this, clazz);
    }

    @Override
    public <O extends Container> O getParentContainer(Object source, Class<O> clazz) {
        return SwingUtil.getParentContainer(source, clazz);
    }

    @Override
    public <T> void removeContextValue(Class<T> clazz) {
        delegateContext.removeContextValue(clazz, null);
    }

    @Override
    public <T> void removeContextValue(Class<T> clazz, String name) {
        delegateContext.removeContextValue(clazz, name);
    }

    @Override
    public <T> void setContextValue(T o) {
        delegateContext.setContextValue(o, null);
    }

    @Override
    public <T> void setContextValue(T o, String name) {
        delegateContext.setContextValue(o, name);
    }

    /*-----------------------------------------------------------------------*/
    /*----------------------- Public acessor methods  -----------------------*/
    /*-----------------------------------------------------------------------*/

    public java.lang.Boolean getActif() {
        return actif;
    }

    public org.sharengo.wikitty.TreeNode getBean() {
        return bean;
    }

    public javax.swing.JComboBox getCombo() {
        return combo;
    }

    public java.lang.Boolean getDeletable() {
        return deletable;
    }

    public javax.swing.JLabel getLabel() {
        return label;
    }

    public java.lang.String getLabelName() {
        return labelName;
    }

    public java.lang.Boolean isActif() {
        return actif !=null && actif;
    }

    public java.lang.Boolean isDeletable() {
        return deletable !=null && deletable;
    }

    /*-----------------------------------------------------------------------*/
    /*----------------------- Public mutator methods  -----------------------*/
    /*-----------------------------------------------------------------------*/

    public void setActif(java.lang.Boolean newValue) {
        java.lang.Boolean oldValue = this.actif;
        this.actif = newValue;
        firePropertyChange(PROPERTY_ACTIF, oldValue, newValue);
    }

    public void setBean(org.sharengo.wikitty.TreeNode newValue) {
        org.sharengo.wikitty.TreeNode oldValue = this.bean;
        this.bean = newValue;
        firePropertyChange(PROPERTY_BEAN, oldValue, newValue);
    }

    public void setDeletable(java.lang.Boolean newValue) {
        java.lang.Boolean oldValue = this.deletable;
        this.deletable = newValue;
        firePropertyChange(PROPERTY_DELETABLE, oldValue, newValue);
    }

    public void setLabelName(java.lang.String newValue) {
        java.lang.String oldValue = this.labelName;
        this.labelName = newValue;
        firePropertyChange(PROPERTY_LABEL_NAME, oldValue, newValue);
    }

    /*-----------------------------------------------------------------------*/
    /*--------------------- Components creation methods ---------------------*/
    /*-----------------------------------------------------------------------*/

    protected void addChildrenToVradiCriteriaField() {
        if (!allComponentsCreated) {
            return;
        }
        add(label, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0, 10, 2, new Insets(0, 2, 0, 0), 0, 0));
        add(combo, new GridBagConstraints(0, 1, 1, 1, 1.0, 0.0, 10, 2, new Insets(0, 0, 0, 0), 0, 0));
    }

    protected void createActif() {
        $objectMap.put("actif", actif = true);
    }

    protected void createBean() {
        $objectMap.put("bean", bean = null);
    }

    protected void createCombo() {
        $objectMap.put("combo", combo = new javax.swing.JComboBox());
        combo.setName("combo");
    }

    protected void createDeletable() {
        $objectMap.put("deletable", deletable = false);
    }

    protected void createLabel() {
        $objectMap.put("label", label = new javax.swing.JLabel());
        label.setName("label");
    }

    protected void createLabelName() {
        $objectMap.put("labelName", labelName = "");
    }

    /*-----------------------------------------------------------------------*/
    /*------------------------ Internal jaxx methods ------------------------*/
    /*-----------------------------------------------------------------------*/

    private void $completeSetup() {
        allComponentsCreated = true;
        addChildrenToVradiCriteriaField();
        
        // apply 3 data bindings
        JAXXUtil.applyDataBinding(this, $bindings.keySet());
        
        $afterCompleteSetup();
    }

    private void $initialize() {
        if (allComponentsCreated || !contextInitialized) {
            return;
        }
        // registers 3 data bindings
        $registerDefaultBindings();
        $objectMap.put("vradiCriteriaField", this);
        createLabelName();
        createBean();
        createDeletable();
        createActif();
        rootItem = null;
        createLabel();
        createCombo();
        // inline creation of vradiCriteriaField
        setName("vradiCriteriaField");
        
        $completeSetup();
    }

    private void $registerDefaultBindings() {
        // register 3 data bindings
        registerDataBinding(new SimpleJAXXObjectBinding(this, BINDING_LABEL_ENABLED, true ,"actif") {
        
            @Override
            public void processDataBinding() {
                label.setEnabled(isActif());
            }
        });
        registerDataBinding(new SimpleJAXXObjectBinding(this, BINDING_LABEL_TEXT, true ,"labelName") {
        
            @Override
            public void processDataBinding() {
                label.setText(_(getLabelName()));
            }
        });
        registerDataBinding(new SimpleJAXXObjectBinding(this, BINDING_COMBO_ENABLED, true ,"actif") {
        
            @Override
            public void processDataBinding() {
                combo.setEnabled(isActif());
            }
        });
    }

}
